@@ -112,7 +112,10 @@ class Hardware(BaseHardware):
           elif bid >= 0 and data[10] != bid:
             pass
           else:
-            st = 'Capture from Hermes device: Mac %2x:%2x:%2x:%2x:%2x:%2x, Code version %d, ID %d' % tuple(data[3:11])
+            dta = data[3:10]
+            dta.append(data[0x15])
+            dta.append(data[10])
+            st = 'Capture from Hermes device: Mac %2x:%2x:%2x:%2x:%2x:%2x, Code version %d.%d, ID %d' % tuple(dta)
             self.hermes_mac = data[3:9]
             self.hermes_ip = addr[0]
             self.hermes_code_version = data[9]
