@@ -19,6 +19,7 @@
 #define MIC_OUT_RATE		48000		// mic post-processing sample rate
 #define PA_LIST_SIZE 		16			// max number of pulseaudio devices
 #define QUISK_MAX_RECEIVERS	9			// max number of receiver channels
+#define START_CW_DELAY_MAX	250		// Maximum delay for start_cw_delay
 
 // Test the audio: 0 == No test; normal operation;
 // 1 == Copy real data to the output; 2 == copy imaginary data to the output;
@@ -297,6 +298,8 @@ extern play_state_t quisk_play_state;		// startup, receiving, sidetone
 extern int freedv_current_mode;			// current FreeDV mode; 700D, @)@) etc.
 extern int n_modem_sample_rate;			// Receive data, decimate to modem_sample_rate, FreeDV codec output data at speech_sample_rate
 extern int n_speech_sample_rate;		// Microphone decimate to speech_sample_rate, Freedv codec output data at modem_sample_rate, interpolate to 48000
+extern int quisk_start_cw_delay;		// milliseconds to delay output on serial or MIDI CW key down
+extern int quisk_start_ssb_delay;		// milliseconds to discard output for all modes except CW
 
 extern PyObject * quisk_set_spot_level(PyObject * , PyObject *);
 extern PyObject * quisk_get_tx_filter(PyObject * , PyObject *);
