@@ -289,6 +289,7 @@ class SliderBoxV(wx.BoxSizer):
     wx.BoxSizer.__init__(self, wx.VERTICAL)
     self.slider = wx.Slider(parent, -1, init, themin, themax, style=wx.SL_VERTICAL|wx.SL_INVERSE)
     self.slider.Bind(wx.EVT_SCROLL, handler)
+    self.handler = handler
     sw, sh = self.slider.GetSize()
     self.text = text
     self.themin = themin
@@ -333,6 +334,18 @@ class SliderBoxV(wx.BoxSizer):
   def SetValue(self, value):
     # Set slider visual position; does not call handler
     self.slider.SetValue(value)
+  def GetDecValue(self):	# Return the value 0.0 to 1.0
+    return float(self.slider.GetValue() - self.themin) / (self.themax - self.themin)
+  def SetDecValue(self, value, do_cmd=True):	# Set the value with a decimal 0.0 to 1.0
+    if value < 0.0:
+      value = 0.0
+    elif value > 1.0:
+      value = 1.0
+    value = value * (self.themax - self.themin) + self.themin
+    value = int(value + 0.5)
+    self.slider.SetValue(value)
+    if do_cmd:
+      self.handler(None)
 
 class QuiskText1(wx.lib.stattext.GenStaticText):
   # Self-drawn text for QuiskText.
